#
# spec file for package libtool
#
# Copyright (c) 2022-2023 ZhuningOS
#


#####################################################################
#                                                                   #
#   NOTE: PLEASE RUN pre_checkin.sh BEFORE SUBMITTING THE PACKAGE   #
#                                                                   #
#####################################################################
Name:           libtool
Version:        2.4.6
Release:        3.4.1
Summary:        A Tool to Build Shared Libraries
License:        GPL-2.0+ and LGPL-2.1+ and GFDL-1.2+
Group:          Development/Tools/Building
Url:            http://www.gnu.org/software/libtool/
Source0:        http://ftp.gnu.org/gnu/libtool/libtool-%{version}.tar.xz
Source1:        http://ftp.gnu.org/gnu/libtool/libtool-%{version}.tar.xz.sig
Source2:        libtool.keyring
Source3:        baselibs.conf
Source4:        libtool-rpmlintrc
Patch0:         libtool-no_host_name.patch
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gcc-objc
BuildRequires:  help2man
BuildRequires:  lzma
BuildRequires:  makeinfo
BuildRequires:  zlib-devel
Requires:       automake > 1.4
Requires:       libltdl7 = %{version}
Requires:       m4 >= 1.4.16
Requires:       tar
Requires(preun): %{install_info_prereq}
Requires(post): %{install_info_prereq}
Provides:       libltdl-devel
# fedora name
Provides:       libtool-ltdl-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNU libtool is a set of shell scripts to automatically configure UNIX
architectures to build shared libraries in a generic fashion.

%package -n libltdl7
Summary:        Libtool Runtime Library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++

%description -n libltdl7
Library needed by programs that use the ltdl interface of GNU libtool.

%prep
%setup -q -n libtool-%{version}
%patch0

%build
./configure CFLAGS="%{optflags}" \
   --prefix=/usr --infodir=%{_infodir} --libdir=%{_libdir}
# force rebuild with non-broken makeinfo
rm -f doc/libtool.info
make V=1 %{?_smp_mflags}

%if "%{name}" == "libtool-testsuite"
%check
trap 'test $? -ne 0 && cat tests/testsuite.log' EXIT
# Avoid spurious testsuite failures due to messages from icecream
PATH=%{_prefix}/bin:$PATH
make %{?_smp_mflags} check

%install
%else
%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
chmod +x %{buildroot}%{_datadir}/libtool/build-aux/ltmain.sh
%endif

%post
%install_info --info-dir=%{_infodir} %{_infodir}/libtool.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/libtool.info-1.gz
%install_info --info-dir=%{_infodir} %{_infodir}/libtool.info-2.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libtool.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libtool.info-1.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/libtool.info-2.gz

%post -n libltdl7 -p /sbin/ldconfig

%postun -n libltdl7 -p /sbin/ldconfig

%if "%{name}" == "libtool"
%files
%defattr(-, root, root)
%doc AUTHORS NEWS README THANKS ChangeLog COPYING
%{_bindir}/libtool
%{_bindir}/libtoolize
%{_includedir}/libltdl
%{_includedir}/ltdl.h
%{_libdir}/libltdl.a
%attr(644, root, root) %{_libdir}/libltdl.la
%{_libdir}/libltdl.so
%{_datadir}/aclocal/*.m4
%doc %{_infodir}/libtool.info*
%doc %{_mandir}/man1/libtool.1.gz
%doc %{_mandir}/man1/libtoolize.1.gz
%{_datadir}/libtool

%files -n libltdl7
%defattr(-, root, root)
%{_libdir}/libltdl.so.*
%endif

%changelog
